=======
History
=======

0.2.0 (2021-04-25)
--------------------------------------------------------

* Implemented brute force functions
* Increased testing of perfect and maximum matching enumerators
* Fixed maximum matching enumeration (some results were missing)
* improve code cleanness

0.1.16 (2021-04-04)
--------------------------------------------------------

* Iterators extended: top_nodes, bottom_nodes
* More graphics utils
* Removed plot_bipartite, only draw functions now


0.1.15 (2021-04-04)
--------------------------------------------------------

* Iterators implemented: top_nodes, bottom_nodes
* Utils to plot with matplotlib: draw_bipartite, plot_bipartite


0.1.10 (2021-04-02)
--------------------------------------------------------

* Functions already available: enum_perfect_matchings and enum_maximum_matchings
* Readme files updated


0.1.0 (2021-02-14)
--------------------------------------------------------

* First release on PyPI.
